"""The instrument commands module.

These commands are used in the following models:
AWG5K, AWG5KC, AWG7K, AWG7KC

THIS FILE IS AUTO-GENERATED, IT SHOULD NOT BE MANUALLY MODIFIED.

Please report an issue if one is found.

Commands and Queries:

::

    - INSTrument:COUPle:SOURce <state>
    - INSTrument:COUPle:SOURce?
"""
from typing import Optional, TYPE_CHECKING

from .._helpers import SCPICmdRead, SCPICmdWrite

if TYPE_CHECKING:
    from tm_devices.drivers.pi.pi_device import PIDevice


class InstrumentCoupleSource(SCPICmdWrite, SCPICmdRead):
    r"""The ``INSTrument:COUPle:SOURce`` command.

    **Description:**
        - This command and query sets or returns the coupled state for a channel.

    **Usage:**
        - Using the ``.query()`` method will send the ``INSTrument:COUPle:SOURce?`` query.
        - Using the ``.verify(value)`` method will send the ``INSTrument:COUPle:SOURce?`` query and
          raise an AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``INSTrument:COUPle:SOURce value``
          command.

    **SCPI Syntax:**

    ::

        - INSTrument:COUPle:SOURce <state>
        - INSTrument:COUPle:SOURce?

    **Info:**
        - ``<state>`` ::={NONE\|PAIR\|ALL}.
        - ``NONE``
        - ``PAIR`` - CH1 to CH2 and CH3 to CH4.
        - ``ALL`` - CH1 to CH2, CH3, and CH4.
    """


class InstrumentCouple(SCPICmdRead):
    """The ``INSTrument:COUPle`` command tree.

    **Usage:**
        - Using the ``.query()`` method will send the ``INSTrument:COUPle?`` query.
        - Using the ``.verify(value)`` method will send the ``INSTrument:COUPle?`` query and raise
          an AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.source``: The ``INSTrument:COUPle:SOURce`` command.
    """

    def __init__(self, device: Optional["PIDevice"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._source = InstrumentCoupleSource(device, f"{self._cmd_syntax}:SOURce")

    @property
    def source(self) -> InstrumentCoupleSource:
        r"""Return the ``INSTrument:COUPle:SOURce`` command.

        **Description:**
            - This command and query sets or returns the coupled state for a channel.

        **Usage:**
            - Using the ``.query()`` method will send the ``INSTrument:COUPle:SOURce?`` query.
            - Using the ``.verify(value)`` method will send the ``INSTrument:COUPle:SOURce?`` query
              and raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``INSTrument:COUPle:SOURce value``
              command.

        **SCPI Syntax:**

        ::

            - INSTrument:COUPle:SOURce <state>
            - INSTrument:COUPle:SOURce?

        **Info:**
            - ``<state>`` ::={NONE\|PAIR\|ALL}.
            - ``NONE``
            - ``PAIR`` - CH1 to CH2 and CH3 to CH4.
            - ``ALL`` - CH1 to CH2, CH3, and CH4.
        """
        return self._source


class Instrument(SCPICmdRead):
    """The ``INSTrument`` command tree.

    **Usage:**
        - Using the ``.query()`` method will send the ``INSTrument?`` query.
        - Using the ``.verify(value)`` method will send the ``INSTrument?`` query and raise an
          AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.couple``: The ``INSTrument:COUPle`` command tree.
    """

    def __init__(self, device: Optional["PIDevice"] = None, cmd_syntax: str = "INSTrument") -> None:
        super().__init__(device, cmd_syntax)
        self._couple = InstrumentCouple(device, f"{self._cmd_syntax}:COUPle")

    @property
    def couple(self) -> InstrumentCouple:
        """Return the ``INSTrument:COUPle`` command tree.

        **Usage:**
            - Using the ``.query()`` method will send the ``INSTrument:COUPle?`` query.
            - Using the ``.verify(value)`` method will send the ``INSTrument:COUPle?`` query and
              raise an AssertionError if the returned value does not match ``value``.

        Sub-properties:
            - ``.source``: The ``INSTrument:COUPle:SOURce`` command.
        """
        return self._couple



"""The calibrate commands module.

These commands are used in the following models:
DPO5KB, DPO70KC, DPO70KD, DPO70KDX, DPO70KSX, DPO7KC, DSA70KC, DSA70KD, MSO5KB, MSO70KC, MSO70KDX

THIS FILE IS AUTO-GENERATED, IT SHOULD NOT BE MANUALLY MODIFIED.

Please report an issue if one is found.

Commands and Queries:

::

    - CALibrate:CALProbe:CH<x>?
    - CALibrate:INTERNal
    - CALibrate:INTERNal:STARt
    - CALibrate:INTERNal:STATus?
    - CALibrate:PRObestate:CH<x>?
    - CALibrate:RESults:SPC?
    - CALibrate:RESults?
    - CALibrate?
"""
from typing import Dict, Optional, TYPE_CHECKING

from .._helpers import (
    DefaultDictPassKeyToFactory,
    SCPICmdRead,
    SCPICmdWriteNoArguments,
    ValidatedChannel,
)

if TYPE_CHECKING:
    from tm_devices.drivers.pi.pi_device import PIDevice


class CalibrateResultsSpc(SCPICmdRead):
    """The ``CALibrate:RESults:SPC`` command.

    **Description:**
        - Returns the status of the SPC operation. This query does not initiate a SPC.

    **Usage:**
        - Using the ``.query()`` method will send the ``CALibrate:RESults:SPC?`` query.
        - Using the ``.verify(value)`` method will send the ``CALibrate:RESults:SPC?`` query and
          raise an AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - CALibrate:RESults:SPC?
    """


class CalibrateResults(SCPICmdRead):
    """The ``CALibrate:RESults`` command.

    **Description:**
        - Returns the status of internal and factory calibrations, without performing any
          calibration operations. The results returned do not include the calibration status of
          attached probes. The query is intended to support GO/NoGO testing of the oscilloscope
          calibration readiness: all returned results should indicate PASS status if the
          oscilloscope is 'fit for duty'. It is quite common, however, to use uncalibrated probes
          (particularly when the oscilloscope inputs are connected into a test system with coaxial
          cables).

    **Usage:**
        - Using the ``.query()`` method will send the ``CALibrate:RESults?`` query.
        - Using the ``.verify(value)`` method will send the ``CALibrate:RESults?`` query and raise
          an AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - CALibrate:RESults?

    Properties:
        - ``.spc``: The ``CALibrate:RESults:SPC`` command.
    """

    def __init__(self, device: Optional["PIDevice"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._spc = CalibrateResultsSpc(device, f"{self._cmd_syntax}:SPC")

    @property
    def spc(self) -> CalibrateResultsSpc:
        """Return the ``CALibrate:RESults:SPC`` command.

        **Description:**
            - Returns the status of the SPC operation. This query does not initiate a SPC.

        **Usage:**
            - Using the ``.query()`` method will send the ``CALibrate:RESults:SPC?`` query.
            - Using the ``.verify(value)`` method will send the ``CALibrate:RESults:SPC?`` query and
              raise an AssertionError if the returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - CALibrate:RESults:SPC?
        """
        return self._spc


class CalibrateProbestateChannel(ValidatedChannel, SCPICmdRead):
    """The ``CALibrate:PRObestate:CH<x>`` command.

    **Description:**
        - This query-only command returns the probe calibration status for the probe of the selected
          channel, 1 through 4.

    **Usage:**
        - Using the ``.query()`` method will send the ``CALibrate:PRObestate:CH<x>?`` query.
        - Using the ``.verify(value)`` method will send the ``CALibrate:PRObestate:CH<x>?`` query
          and raise an AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - CALibrate:PRObestate:CH<x>?
    """


class CalibrateProbestate(SCPICmdRead):
    """The ``CALibrate:PRObestate`` command tree.

    **Usage:**
        - Using the ``.query()`` method will send the ``CALibrate:PRObestate?`` query.
        - Using the ``.verify(value)`` method will send the ``CALibrate:PRObestate?`` query and
          raise an AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.ch``: The ``CALibrate:PRObestate:CH<x>`` command.
    """

    def __init__(self, device: Optional["PIDevice"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._ch: Dict[int, CalibrateProbestateChannel] = DefaultDictPassKeyToFactory(
            lambda x: CalibrateProbestateChannel(device, f"{self._cmd_syntax}:CH{x}")
        )

    @property
    def ch(self) -> Dict[int, CalibrateProbestateChannel]:
        """Return the ``CALibrate:PRObestate:CH<x>`` command.

        **Description:**
            - This query-only command returns the probe calibration status for the probe of the
              selected channel, 1 through 4.

        **Usage:**
            - Using the ``.query()`` method will send the ``CALibrate:PRObestate:CH<x>?`` query.
            - Using the ``.verify(value)`` method will send the ``CALibrate:PRObestate:CH<x>?``
              query and raise an AssertionError if the returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - CALibrate:PRObestate:CH<x>?
        """
        return self._ch


class CalibrateInternalStatus(SCPICmdRead):
    """The ``CALibrate:INTERNal:STATus`` command.

    **Description:**
        - This query-only command returns the current status of the signal path calibration.

    **Usage:**
        - Using the ``.query()`` method will send the ``CALibrate:INTERNal:STATus?`` query.
        - Using the ``.verify(value)`` method will send the ``CALibrate:INTERNal:STATus?`` query and
          raise an AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - CALibrate:INTERNal:STATus?
    """


class CalibrateInternalStart(SCPICmdWriteNoArguments):
    """The ``CALibrate:INTERNal:STARt`` command.

    **Description:**
        - This command (no query form) starts the signal path calibration (SPC) of the analog
          channels. This command is the same as the ``CALIBRATE:INTERNAL`` command. You can use the
          ``CALIBRATE:INTERNAL:STATUS`` query to return the current status of the signal path
          calibration of the instrument.

    **Usage:**
        - Using the ``.write()`` method will send the ``CALibrate:INTERNal:STARt`` command.

    **SCPI Syntax:**

    ::

        - CALibrate:INTERNal:STARt
    """


class CalibrateInternal(SCPICmdWriteNoArguments, SCPICmdRead):
    """The ``CALibrate:INTERNal`` command.

    **Description:**
        - This command (no query form) starts the signal path calibration (SPC) of the instrument.
          You can use the ``CALIBRATE:INTERNAL:STATUS`` query to return the current status of the
          signal path calibration of the instrument.

    **Usage:**
        - Using the ``.write()`` method will send the ``CALibrate:INTERNal`` command.

    **SCPI Syntax:**

    ::

        - CALibrate:INTERNal

    Properties:
        - ``.start``: The ``CALibrate:INTERNal:STARt`` command.
        - ``.status``: The ``CALibrate:INTERNal:STATus`` command.
    """

    def __init__(self, device: Optional["PIDevice"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._start = CalibrateInternalStart(device, f"{self._cmd_syntax}:STARt")
        self._status = CalibrateInternalStatus(device, f"{self._cmd_syntax}:STATus")

    @property
    def start(self) -> CalibrateInternalStart:
        """Return the ``CALibrate:INTERNal:STARt`` command.

        **Description:**
            - This command (no query form) starts the signal path calibration (SPC) of the analog
              channels. This command is the same as the ``CALIBRATE:INTERNAL`` command. You can use
              the ``CALIBRATE:INTERNAL:STATUS`` query to return the current status of the signal
              path calibration of the instrument.

        **Usage:**
            - Using the ``.write()`` method will send the ``CALibrate:INTERNal:STARt`` command.

        **SCPI Syntax:**

        ::

            - CALibrate:INTERNal:STARt
        """
        return self._start

    @property
    def status(self) -> CalibrateInternalStatus:
        """Return the ``CALibrate:INTERNal:STATus`` command.

        **Description:**
            - This query-only command returns the current status of the signal path calibration.

        **Usage:**
            - Using the ``.query()`` method will send the ``CALibrate:INTERNal:STATus?`` query.
            - Using the ``.verify(value)`` method will send the ``CALibrate:INTERNal:STATus?`` query
              and raise an AssertionError if the returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - CALibrate:INTERNal:STATus?
        """
        return self._status


class CalibrateCalprobeChannel(ValidatedChannel, SCPICmdRead):
    """The ``CALibrate:CALProbe:CH<x>`` command.

    **Description:**
        - This query-only command instructs the instrument to perform a probe calibration for the
          selected channel and returns the calibration status. The Channel <x> range is 1 through 4.
          This command is equivalent to selecting Probe Cal from the Vertical menu. You must warm up
          the instrument for at least 20 minutes before running this command.

    **Usage:**
        - Using the ``.query()`` method will send the ``CALibrate:CALProbe:CH<x>?`` query.
        - Using the ``.verify(value)`` method will send the ``CALibrate:CALProbe:CH<x>?`` query and
          raise an AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - CALibrate:CALProbe:CH<x>?
    """


class CalibrateCalprobe(SCPICmdRead):
    """The ``CALibrate:CALProbe`` command tree.

    **Usage:**
        - Using the ``.query()`` method will send the ``CALibrate:CALProbe?`` query.
        - Using the ``.verify(value)`` method will send the ``CALibrate:CALProbe?`` query and raise
          an AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.ch``: The ``CALibrate:CALProbe:CH<x>`` command.
    """

    def __init__(self, device: Optional["PIDevice"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._ch: Dict[int, CalibrateCalprobeChannel] = DefaultDictPassKeyToFactory(
            lambda x: CalibrateCalprobeChannel(device, f"{self._cmd_syntax}:CH{x}")
        )

    @property
    def ch(self) -> Dict[int, CalibrateCalprobeChannel]:
        """Return the ``CALibrate:CALProbe:CH<x>`` command.

        **Description:**
            - This query-only command instructs the instrument to perform a probe calibration for
              the selected channel and returns the calibration status. The Channel <x> range is 1
              through 4. This command is equivalent to selecting Probe Cal from the Vertical menu.
              You must warm up the instrument for at least 20 minutes before running this command.

        **Usage:**
            - Using the ``.query()`` method will send the ``CALibrate:CALProbe:CH<x>?`` query.
            - Using the ``.verify(value)`` method will send the ``CALibrate:CALProbe:CH<x>?`` query
              and raise an AssertionError if the returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - CALibrate:CALProbe:CH<x>?
        """
        return self._ch


class Calibrate(SCPICmdRead):
    """The ``CALibrate`` command.

    **Description:**
        - This query returns the status of signal path calibration.

    **Usage:**
        - Using the ``.query()`` method will send the ``CALibrate?`` query.
        - Using the ``.verify(value)`` method will send the ``CALibrate?`` query and raise an
          AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - CALibrate?

    Properties:
        - ``.calprobe``: The ``CALibrate:CALProbe`` command tree.
        - ``.internal``: The ``CALibrate:INTERNal`` command.
        - ``.probestate``: The ``CALibrate:PRObestate`` command tree.
        - ``.results``: The ``CALibrate:RESults`` command.
    """

    def __init__(self, device: Optional["PIDevice"] = None, cmd_syntax: str = "CALibrate") -> None:
        super().__init__(device, cmd_syntax)
        self._calprobe = CalibrateCalprobe(device, f"{self._cmd_syntax}:CALProbe")
        self._internal = CalibrateInternal(device, f"{self._cmd_syntax}:INTERNal")
        self._probestate = CalibrateProbestate(device, f"{self._cmd_syntax}:PRObestate")
        self._results = CalibrateResults(device, f"{self._cmd_syntax}:RESults")

    @property
    def calprobe(self) -> CalibrateCalprobe:
        """Return the ``CALibrate:CALProbe`` command tree.

        **Usage:**
            - Using the ``.query()`` method will send the ``CALibrate:CALProbe?`` query.
            - Using the ``.verify(value)`` method will send the ``CALibrate:CALProbe?`` query and
              raise an AssertionError if the returned value does not match ``value``.

        Sub-properties:
            - ``.ch``: The ``CALibrate:CALProbe:CH<x>`` command.
        """
        return self._calprobe

    @property
    def internal(self) -> CalibrateInternal:
        """Return the ``CALibrate:INTERNal`` command.

        **Description:**
            - This command (no query form) starts the signal path calibration (SPC) of the
              instrument. You can use the ``CALIBRATE:INTERNAL:STATUS`` query to return the current
              status of the signal path calibration of the instrument.

        **Usage:**
            - Using the ``.write()`` method will send the ``CALibrate:INTERNal`` command.

        **SCPI Syntax:**

        ::

            - CALibrate:INTERNal

        Sub-properties:
            - ``.start``: The ``CALibrate:INTERNal:STARt`` command.
            - ``.status``: The ``CALibrate:INTERNal:STATus`` command.
        """
        return self._internal

    @property
    def probestate(self) -> CalibrateProbestate:
        """Return the ``CALibrate:PRObestate`` command tree.

        **Usage:**
            - Using the ``.query()`` method will send the ``CALibrate:PRObestate?`` query.
            - Using the ``.verify(value)`` method will send the ``CALibrate:PRObestate?`` query and
              raise an AssertionError if the returned value does not match ``value``.

        Sub-properties:
            - ``.ch``: The ``CALibrate:PRObestate:CH<x>`` command.
        """
        return self._probestate

    @property
    def results(self) -> CalibrateResults:
        """Return the ``CALibrate:RESults`` command.

        **Description:**
            - Returns the status of internal and factory calibrations, without performing any
              calibration operations. The results returned do not include the calibration status of
              attached probes. The query is intended to support GO/NoGO testing of the oscilloscope
              calibration readiness: all returned results should indicate PASS status if the
              oscilloscope is 'fit for duty'. It is quite common, however, to use uncalibrated
              probes (particularly when the oscilloscope inputs are connected into a test system
              with coaxial cables).

        **Usage:**
            - Using the ``.query()`` method will send the ``CALibrate:RESults?`` query.
            - Using the ``.verify(value)`` method will send the ``CALibrate:RESults?`` query and
              raise an AssertionError if the returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - CALibrate:RESults?

        Sub-properties:
            - ``.spc``: The ``CALibrate:RESults:SPC`` command.
        """
        return self._results



"""AWG70KB device driver module."""
from tm_devices.commands import AWG70KBMixin
from tm_devices.drivers.pi.signal_sources.awgs.awg70ka import AWG70KA


class AWG70KB(AWG70KBMixin, AWG70KA):
    """AWG70KB device driver."""



# ruff: noqa: D402,PLR0913
# pyright: reportConstantRedefinition=none
"""The status commands module.

These commands are used in the following models:
DAQ6510, SMU2450, SMU2460, SMU2461, SMU2470

THIS FILE IS AUTO-GENERATED, IT SHOULD NOT BE MANUALLY MODIFIED.

Please report an issue if one is found.

Attributes and Functions:

::

    - status.clear()
    - status.condition
    - status.operation.condition
    - status.operation.enable
    - status.operation.event
    - status.operation.getmap()
    - status.operation.setmap()
    - status.preset()
    - status.questionable.condition
    - status.questionable.enable
    - status.questionable.event
    - status.questionable.getmap()
    - status.questionable.setmap()
    - status.request_enable
    - status.standard.enable
    - status.standard.event
"""
from typing import Optional, TYPE_CHECKING, Union

from .._helpers import BaseTSPCmd, NoDeviceProvidedError

if TYPE_CHECKING:
    from tm_devices.drivers.pi.tsp_device import TSPDevice


class StatusStandard(BaseTSPCmd):
    r"""The ``status.standard`` command tree.

    Constants:
        - ``.OPC``: B0. Set bit indicates that all pending selected instrument operations are
          completed and the instrument is ready to accept new commands. The bit is set in response
          to an \*OPC command. The opc() function can be used in place of the \*OPC command.
        - ``.PON``: B7. Set bit indicates that the instrument has been turned off and turned back on
          since the last time this register has been read.
        - ``.QYE``: B2. Set bit indicates that you attempted to read data from an empty Output
          Queue.

    Properties/methods:
        - ``.enable``: The ``status.standard.enable`` attribute.
        - ``.event``: The ``status.standard.event`` attribute.
    """

    OPC = "status.standard.OPC"
    r"""str: B0. Set bit indicates that all pending selected instrument operations are completed and the instrument is ready to accept new commands. The bit is set in response to an \*OPC command. The opc() function can be used in place of the \*OPC command."""  # noqa: E501
    PON = "status.standard.PON"
    """str: B7. Set bit indicates that the instrument has been turned off and turned back on since the last time this register has been read."""  # noqa: E501
    QYE = "status.standard.QYE"
    """str: B2. Set bit indicates that you attempted to read data from an empty Output Queue."""

    @property
    def enable(self) -> str:
        """Access the ``status.standard.enable`` attribute.

        **Description:**
            - This attribute reads or sets the bits in the Status Enable register of the Standard
              Event Register.

        **Usage:**
            - Accessing this property will send the ``print(status.standard.enable)`` query.
            - Setting this property to a value will send the ``status.standard.enable = value``
              command.

        **TSP Syntax:**

        ::

            - status.standard.enable = value
            - print(status.standard.enable)

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            if self._device.command_syntax_enabled:  # type: ignore[union-attr]
                return self._cmd_syntax + ".enable"
            return self._device.query(  # type: ignore[union-attr]
                f"print({self._cmd_syntax}.enable)"
            )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to access the ``{self._cmd_syntax}.enable`` attribute."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    @enable.setter
    def enable(self, value: Union[str, float]) -> None:
        """Access the ``status.standard.enable`` attribute.

        **Description:**
            - This attribute reads or sets the bits in the Status Enable register of the Standard
              Event Register.

        **Usage:**
            - Accessing this property will send the ``print(status.standard.enable)`` query.
            - Setting this property to a value will send the ``status.standard.enable = value``
              command.

        **TSP Syntax:**

        ::

            - status.standard.enable = value
            - print(status.standard.enable)

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            if self._device.command_verification_enabled:  # type: ignore[union-attr]
                self._device.set_and_check(  # type: ignore[union-attr]
                    self._cmd_syntax + ".enable", value
                )
            else:
                self._device.write(  # type: ignore[union-attr]
                    f"{self._cmd_syntax}.enable = {value}"
                )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to access the ``{self._cmd_syntax}.enable`` attribute."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    @property
    def event(self) -> str:
        """Access the ``status.standard.event`` attribute.

        **Description:**
            - This attribute returns the contents of the Standard Event Status Register set of the
              status model.

        **Usage:**
            - Accessing this property will send the ``print(status.standard.event)`` query.

        **TSP Syntax:**

        ::

            - print(status.standard.event)

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            if self._device.command_syntax_enabled:  # type: ignore[union-attr]
                return self._cmd_syntax + ".event"
            return self._device.query(  # type: ignore[union-attr]
                f"print({self._cmd_syntax}.event)"
            )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to access the ``{self._cmd_syntax}.event`` attribute."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error


class StatusQuestionable(BaseTSPCmd):
    """The ``status.questionable`` command tree.

    Properties/methods:
        - ``.condition``: The ``status.questionable.condition`` attribute.
        - ``.enable``: The ``status.questionable.enable`` attribute.
        - ``.event``: The ``status.questionable.event`` attribute.
        - ``.getmap()``: The ``status.questionable.getmap()`` function.
        - ``.setmap()``: The ``status.questionable.setmap()`` function.
    """

    @property
    def condition(self) -> str:
        """Access the ``status.questionable.condition`` attribute.

        **Description:**
            - This attribute reads the Questionable Condition Register of the status model.

        **Usage:**
            - Accessing this property will send the ``print(status.questionable.condition)`` query.

        **TSP Syntax:**

        ::

            - print(status.questionable.condition)

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            if self._device.command_syntax_enabled:  # type: ignore[union-attr]
                return self._cmd_syntax + ".condition"
            return self._device.query(  # type: ignore[union-attr]
                f"print({self._cmd_syntax}.condition)"
            )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to access the ``{self._cmd_syntax}.condition`` attribute."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    @property
    def enable(self) -> str:
        """Access the ``status.questionable.enable`` attribute.

        **Description:**
            - This attribute sets or reads the contents of the questionable event enable register of
              the status model.

        **Usage:**
            - Accessing this property will send the ``print(status.questionable.enable)`` query.
            - Setting this property to a value will send the ``status.questionable.enable = value``
              command.

        **TSP Syntax:**

        ::

            - status.questionable.enable = value
            - print(status.questionable.enable)

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            if self._device.command_syntax_enabled:  # type: ignore[union-attr]
                return self._cmd_syntax + ".enable"
            return self._device.query(  # type: ignore[union-attr]
                f"print({self._cmd_syntax}.enable)"
            )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to access the ``{self._cmd_syntax}.enable`` attribute."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    @enable.setter
    def enable(self, value: Union[str, float]) -> None:
        """Access the ``status.questionable.enable`` attribute.

        **Description:**
            - This attribute sets or reads the contents of the questionable event enable register of
              the status model.

        **Usage:**
            - Accessing this property will send the ``print(status.questionable.enable)`` query.
            - Setting this property to a value will send the ``status.questionable.enable = value``
              command.

        **TSP Syntax:**

        ::

            - status.questionable.enable = value
            - print(status.questionable.enable)

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            if self._device.command_verification_enabled:  # type: ignore[union-attr]
                self._device.set_and_check(  # type: ignore[union-attr]
                    self._cmd_syntax + ".enable", value
                )
            else:
                self._device.write(  # type: ignore[union-attr]
                    f"{self._cmd_syntax}.enable = {value}"
                )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to access the ``{self._cmd_syntax}.enable`` attribute."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    @property
    def event(self) -> str:
        """Access the ``status.questionable.event`` attribute.

        **Description:**
            - This attribute reads the Questionable Event Register.

        **Usage:**
            - Accessing this property will send the ``print(status.questionable.event)`` query.

        **TSP Syntax:**

        ::

            - print(status.questionable.event)

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            if self._device.command_syntax_enabled:  # type: ignore[union-attr]
                return self._cmd_syntax + ".event"
            return self._device.query(  # type: ignore[union-attr]
                f"print({self._cmd_syntax}.event)"
            )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to access the ``{self._cmd_syntax}.event`` attribute."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    def getmap(self, bit_number: int) -> str:
        """Run the ``status.questionable.getmap()`` function.

        **Description:**
            - This function requests the mapped set event and mapped clear event status for a bit in
              the Questionable Event Registers.

        **TSP Syntax:**

        ::

            - status.questionable.getmap()

        Args:
            bit_number: The bit number to check (0 to 14).

        Returns:
            The result of the function call.

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            return self._device.query(  # type: ignore[union-attr]
                f"print({self._cmd_syntax}.getmap({bit_number}))"
            )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to run the ``{self._cmd_syntax}.getmap()`` function."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    def setmap(self, bit_number: int, set_event: int, clear_event: Optional[int] = None) -> None:
        """Run the ``status.questionable.setmap()`` function.

        **Description:**
            - This function maps events to bits in the questionable event registers.

        **TSP Syntax:**

        ::

            - status.questionable.setmap()

        Args:
            bit_number: The bit number that is mapped to an event (0 to 14).
            set_event: The number of the event that sets the bits in the condition and event
                registers; 0 if no mapping.
            clear_event (optional): The number of the event that clears the bit in the condition
                register; 0 if no mapping.

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            function_args = ", ".join(
                str(x)
                for x in (
                    bit_number,
                    set_event,
                    clear_event,
                )
                if x is not None
            )
            self._device.write(  # type: ignore[union-attr]
                f"{self._cmd_syntax}.setmap({function_args})"
            )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to run the ``{self._cmd_syntax}.setmap()`` function."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error


class StatusOperation(BaseTSPCmd):
    """The ``status.operation`` command tree.

    Properties/methods:
        - ``.condition``: The ``status.operation.condition`` attribute.
        - ``.enable``: The ``status.operation.enable`` attribute.
        - ``.event``: The ``status.operation.event`` attribute.
        - ``.getmap()``: The ``status.operation.getmap()`` function.
        - ``.setmap()``: The ``status.operation.setmap()`` function.
    """

    @property
    def condition(self) -> str:
        """Access the ``status.operation.condition`` attribute.

        **Description:**
            - This attribute reads the Operation Event Register of the status model.

        **Usage:**
            - Accessing this property will send the ``print(status.operation.condition)`` query.

        **TSP Syntax:**

        ::

            - print(status.operation.condition)

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            if self._device.command_syntax_enabled:  # type: ignore[union-attr]
                return self._cmd_syntax + ".condition"
            return self._device.query(  # type: ignore[union-attr]
                f"print({self._cmd_syntax}.condition)"
            )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to access the ``{self._cmd_syntax}.condition`` attribute."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    @property
    def enable(self) -> str:
        """Access the ``status.operation.enable`` attribute.

        **Description:**
            - This attribute sets or reads the contents of the Operation Event Enable Register of
              the status model.

        **Usage:**
            - Accessing this property will send the ``print(status.operation.enable)`` query.
            - Setting this property to a value will send the ``status.operation.enable = value``
              command.

        **TSP Syntax:**

        ::

            - status.operation.enable = value
            - print(status.operation.enable)

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            if self._device.command_syntax_enabled:  # type: ignore[union-attr]
                return self._cmd_syntax + ".enable"
            return self._device.query(  # type: ignore[union-attr]
                f"print({self._cmd_syntax}.enable)"
            )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to access the ``{self._cmd_syntax}.enable`` attribute."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    @enable.setter
    def enable(self, value: Union[str, float]) -> None:
        """Access the ``status.operation.enable`` attribute.

        **Description:**
            - This attribute sets or reads the contents of the Operation Event Enable Register of
              the status model.

        **Usage:**
            - Accessing this property will send the ``print(status.operation.enable)`` query.
            - Setting this property to a value will send the ``status.operation.enable = value``
              command.

        **TSP Syntax:**

        ::

            - status.operation.enable = value
            - print(status.operation.enable)

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            if self._device.command_verification_enabled:  # type: ignore[union-attr]
                self._device.set_and_check(  # type: ignore[union-attr]
                    self._cmd_syntax + ".enable", value
                )
            else:
                self._device.write(  # type: ignore[union-attr]
                    f"{self._cmd_syntax}.enable = {value}"
                )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to access the ``{self._cmd_syntax}.enable`` attribute."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    @property
    def event(self) -> str:
        """Access the ``status.operation.event`` attribute.

        **Description:**
            - This attribute reads the Operation Event Register of the status model.

        **Usage:**
            - Accessing this property will send the ``print(status.operation.event)`` query.

        **TSP Syntax:**

        ::

            - print(status.operation.event)

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            if self._device.command_syntax_enabled:  # type: ignore[union-attr]
                return self._cmd_syntax + ".event"
            return self._device.query(  # type: ignore[union-attr]
                f"print({self._cmd_syntax}.event)"
            )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to access the ``{self._cmd_syntax}.event`` attribute."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    def getmap(self, bit_number: int) -> str:
        """Run the ``status.operation.getmap()`` function.

        **Description:**
            - This function requests the mapped set event and mapped clear event status for a bit in
              the Operation Event Registers.

        **TSP Syntax:**

        ::

            - status.operation.getmap()

        Args:
            bit_number: The bit number to check.

        Returns:
            The result of the function call.

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            return self._device.query(  # type: ignore[union-attr]
                f"print({self._cmd_syntax}.getmap({bit_number}))"
            )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to run the ``{self._cmd_syntax}.getmap()`` function."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    def setmap(self, bit_number: int, set_event: int, clear_event: Optional[int] = None) -> None:
        """Run the ``status.operation.setmap()`` function.

        **Description:**
            - This function allows you to map events to bits in the Operation Event Register.

        **TSP Syntax:**

        ::

            - status.operation.setmap()

        Args:
            bit_number: The bit number that is mapped to an event (0 to 14).
            set_event: The number of the event that sets the bits in the condition and event
                registers; 0 if no mapping.
            clear_event (optional): The number of the event that clears the bit in the condition
                register; 0 if no mapping.

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            function_args = ", ".join(
                str(x)
                for x in (
                    bit_number,
                    set_event,
                    clear_event,
                )
                if x is not None
            )
            self._device.write(  # type: ignore[union-attr]
                f"{self._cmd_syntax}.setmap({function_args})"
            )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to run the ``{self._cmd_syntax}.setmap()`` function."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error


class Status(BaseTSPCmd):
    """The ``status`` command tree.

    Constants:
        - ``.EAV``: B2. Set summary bit indicates that an error or status message is present in the
          Error Queue.
        - ``.ESB``: B5. Set summary bit indicates that an enabled standard event has occurred.
        - ``.MAV``: B4. Set summary bit indicates that a response message is present in the Output
          Queue.
        - ``.MSB``: B0. Set summary bit indicates that an enabled measurement event has occurred.
        - ``.MSS``: An enabled summary bit of the status byte register is set.
        - ``.OSB``: B7. Set summary bit indicates that an enabled operation event has occurred.
        - ``.QSB``: B3. Set summary bit indicates that an enabled questionable event has occurred.

    Properties/methods:
        - ``.clear()``: The ``status.clear()`` function.
        - ``.condition``: The ``status.condition`` attribute.
        - ``.operation``: The ``status.operation`` command tree.
        - ``.preset()``: The ``status.preset()`` function.
        - ``.questionable``: The ``status.questionable`` command tree.
        - ``.request_enable``: The ``status.request_enable`` attribute.
        - ``.standard``: The ``status.standard`` command tree.
    """

    EAV = "status.EAV"
    """str: B2. Set summary bit indicates that an error or status message is present in the Error Queue."""  # noqa: E501
    ESB = "status.ESB"
    """str: B5. Set summary bit indicates that an enabled standard event has occurred."""
    MAV = "status.MAV"
    """str: B4. Set summary bit indicates that a response message is present in the Output Queue."""
    MSB = "status.MSB"
    """str: B0. Set summary bit indicates that an enabled measurement event has occurred."""
    MSS = "status.MSS"
    """str: An enabled summary bit of the status byte register is set."""
    OSB = "status.OSB"
    """str: B7. Set summary bit indicates that an enabled operation event has occurred."""
    QSB = "status.QSB"
    """str: B3. Set summary bit indicates that an enabled questionable event has occurred."""

    def __init__(self, device: Optional["TSPDevice"] = None, cmd_syntax: str = "status") -> None:
        super().__init__(device, cmd_syntax)
        self._operation = StatusOperation(device, f"{self._cmd_syntax}.operation")
        self._questionable = StatusQuestionable(device, f"{self._cmd_syntax}.questionable")
        self._standard = StatusStandard(device, f"{self._cmd_syntax}.standard")

    @property
    def condition(self) -> str:
        """Access the ``status.condition`` attribute.

        **Description:**
            - This attribute stores the status byte condition register.

        **Usage:**
            - Accessing this property will send the ``print(status.condition)`` query.

        **TSP Syntax:**

        ::

            - print(status.condition)

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            if self._device.command_syntax_enabled:  # type: ignore[union-attr]
                return self._cmd_syntax + ".condition"
            return self._device.query(  # type: ignore[union-attr]
                f"print({self._cmd_syntax}.condition)"
            )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to access the ``{self._cmd_syntax}.condition`` attribute."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    @property
    def operation(self) -> StatusOperation:
        """Return the ``status.operation`` command tree.

        Sub-properties/methods:
            - ``.condition``: The ``status.operation.condition`` attribute.
            - ``.enable``: The ``status.operation.enable`` attribute.
            - ``.event``: The ``status.operation.event`` attribute.
            - ``.getmap()``: The ``status.operation.getmap()`` function.
            - ``.setmap()``: The ``status.operation.setmap()`` function.
        """
        return self._operation

    @property
    def questionable(self) -> StatusQuestionable:
        """Return the ``status.questionable`` command tree.

        Sub-properties/methods:
            - ``.condition``: The ``status.questionable.condition`` attribute.
            - ``.enable``: The ``status.questionable.enable`` attribute.
            - ``.event``: The ``status.questionable.event`` attribute.
            - ``.getmap()``: The ``status.questionable.getmap()`` function.
            - ``.setmap()``: The ``status.questionable.setmap()`` function.
        """
        return self._questionable

    @property
    def request_enable(self) -> str:
        """Access the ``status.request_enable`` attribute.

        **Description:**
            - This attribute stores the settings of the Service Request (SRQ) Enable Register.

        **Usage:**
            - Accessing this property will send the ``print(status.request_enable)`` query.
            - Setting this property to a value will send the ``status.request_enable = value``
              command.

        **TSP Syntax:**

        ::

            - status.request_enable = value
            - print(status.request_enable)

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            if self._device.command_syntax_enabled:  # type: ignore[union-attr]
                return self._cmd_syntax + ".request_enable"
            return self._device.query(  # type: ignore[union-attr]
                f"print({self._cmd_syntax}.request_enable)"
            )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to access the ``{self._cmd_syntax}.request_enable`` attribute."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    @request_enable.setter
    def request_enable(self, value: Union[str, float]) -> None:
        """Access the ``status.request_enable`` attribute.

        **Description:**
            - This attribute stores the settings of the Service Request (SRQ) Enable Register.

        **Usage:**
            - Accessing this property will send the ``print(status.request_enable)`` query.
            - Setting this property to a value will send the ``status.request_enable = value``
              command.

        **TSP Syntax:**

        ::

            - status.request_enable = value
            - print(status.request_enable)

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            if self._device.command_verification_enabled:  # type: ignore[union-attr]
                self._device.set_and_check(  # type: ignore[union-attr]
                    self._cmd_syntax + ".request_enable", value
                )
            else:
                self._device.write(  # type: ignore[union-attr]
                    f"{self._cmd_syntax}.request_enable = {value}"
                )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to access the ``{self._cmd_syntax}.request_enable`` attribute."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    @property
    def standard(self) -> StatusStandard:
        r"""Return the ``status.standard`` command tree.

        Constants:
            - ``.OPC``: B0. Set bit indicates that all pending selected instrument operations are
              completed and the instrument is ready to accept new commands. The bit is set in
              response to an \*OPC command. The opc() function can be used in place of the \*OPC
              command.
            - ``.PON``: B7. Set bit indicates that the instrument has been turned off and turned
              back on since the last time this register has been read.
            - ``.QYE``: B2. Set bit indicates that you attempted to read data from an empty Output
              Queue.

        Sub-properties/methods:
            - ``.enable``: The ``status.standard.enable`` attribute.
            - ``.event``: The ``status.standard.event`` attribute.
        """
        return self._standard

    def clear(self) -> None:
        """Run the ``status.clear()`` function.

        **Description:**
            - This function clears event registers.

        **TSP Syntax:**

        ::

            - status.clear()

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            self._device.write(f"{self._cmd_syntax}.clear()")  # type: ignore[union-attr]
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to run the ``{self._cmd_syntax}.clear()`` function."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    def preset(self) -> None:
        """Run the ``status.preset()`` function.

        **Description:**
            - This function resets all bits in the status model.

        **TSP Syntax:**

        ::

            - status.preset()

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            self._device.write(f"{self._cmd_syntax}.preset()")  # type: ignore[union-attr]
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to run the ``{self._cmd_syntax}.preset()`` function."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error



# ruff: noqa: D402,PLR0913
# pyright: reportConstantRedefinition=none
"""The slot commands module.

These commands are used in the following models:
SS3706A

THIS FILE IS AUTO-GENERATED, IT SHOULD NOT BE MANUALLY MODIFIED.

Please report an issue if one is found.

Attributes and Functions:

::

    - slot[slot].banks.matrix
    - slot[slot].columns.matrix
    - slot[slot].commonsideohms
    - slot[slot].digio
    - slot[slot].idn
    - slot[slot].interlock.override
    - slot[slot].interlock.state
    - slot[slot].isolated
    - slot[slot].matrix
    - slot[slot].maxvoltage
    - slot[slot].multiplexer
    - slot[slot].poles.four
    - slot[slot].poles.one
    - slot[slot].poles.two
    - slot[slot].pseudocard
    - slot[slot].rows.matrix
    - slot[slot].tempsensor
    - slot[slot].thermal.state
"""
from typing import Optional, TYPE_CHECKING, Union

from .._helpers import BaseTSPCmd, NoDeviceProvidedError, ValidatedDynamicNumberCmd

if TYPE_CHECKING:
    from tm_devices.drivers.pi.tsp_device import TSPDevice


class SlotItemThermal(BaseTSPCmd):
    """The ``slot[slot].thermal`` command tree.

    **Info:**
        - ``slot``, the slot number (1 to 6).

    Properties/methods:
        - ``.state``: The ``slot[slot].thermal.state`` attribute.
    """

    @property
    def state(self) -> str:
        """Access the ``slot[slot].thermal.state`` attribute.

        **Description:**
            - This attribute indicates the thermal state of the card in the specified slot.

        **Usage:**
            - Accessing this property will send the ``print(slot[slot].thermal.state)`` query.

        **TSP Syntax:**

        ::

            - print(slot[slot].thermal.state)

        **Info:**
            - ``slot``, the slot number (1 to 6).

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            if self._device.command_syntax_enabled:  # type: ignore[union-attr]
                return self._cmd_syntax + ".state"
            return self._device.query(  # type: ignore[union-attr]
                f"print({self._cmd_syntax}.state)"
            )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to access the ``{self._cmd_syntax}.state`` attribute."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error


class SlotItemRows(BaseTSPCmd):
    """The ``slot[slot].rows`` command tree.

    **Info:**
        - ``slot``, the slot number (1 to 6).

    Properties/methods:
        - ``.matrix``: The ``slot[slot].rows.matrix`` attribute.
    """

    @property
    def matrix(self) -> str:
        """Access the ``slot[slot].rows.matrix`` attribute.

        **Description:**
            - This attribute returns the number of rows in the matrix on the card in the specified
              slot.

        **Usage:**
            - Accessing this property will send the ``print(slot[slot].rows.matrix)`` query.

        **TSP Syntax:**

        ::

            - print(slot[slot].rows.matrix)

        **Info:**
            - ``slot``, the slot number (1 to 6).

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            if self._device.command_syntax_enabled:  # type: ignore[union-attr]
                return self._cmd_syntax + ".matrix"
            return self._device.query(  # type: ignore[union-attr]
                f"print({self._cmd_syntax}.matrix)"
            )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to access the ``{self._cmd_syntax}.matrix`` attribute."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error


class SlotItemPoles(BaseTSPCmd):
    """The ``slot[slot].poles`` command tree.

    **Info:**
        - ``slot``, the slot number (1 to 6).

    Properties/methods:
        - ``.four``: The ``slot[slot].poles.four`` attribute.
        - ``.one``: The ``slot[slot].poles.one`` attribute.
        - ``.two``: The ``slot[slot].poles.two`` attribute.
    """

    @property
    def four(self) -> str:
        """Access the ``slot[slot].poles.four`` attribute.

        **Description:**
            - This attribute indicates if a four-pole setting is supported for the channels on the
              card.

        **Usage:**
            - Accessing this property will send the ``print(slot[slot].poles.four)`` query.

        **TSP Syntax:**

        ::

            - print(slot[slot].poles.four)

        **Info:**
            - ``slot``, the slot number (1 to 6).

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            if self._device.command_syntax_enabled:  # type: ignore[union-attr]
                return self._cmd_syntax + ".four"
            return self._device.query(f"print({self._cmd_syntax}.four)")  # type: ignore[union-attr]
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to access the ``{self._cmd_syntax}.four`` attribute."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    @property
    def one(self) -> str:
        """Access the ``slot[slot].poles.one`` attribute.

        **Description:**
            - This attribute indicates if a one-pole setting is supported for the channels on the
              specified card.

        **Usage:**
            - Accessing this property will send the ``print(slot[slot].poles.one)`` query.

        **TSP Syntax:**

        ::

            - print(slot[slot].poles.one)

        **Info:**
            - ``slot``, the slot number  (1 to 6).

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            if self._device.command_syntax_enabled:  # type: ignore[union-attr]
                return self._cmd_syntax + ".one"
            return self._device.query(f"print({self._cmd_syntax}.one)")  # type: ignore[union-attr]
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to access the ``{self._cmd_syntax}.one`` attribute."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    @property
    def two(self) -> str:
        """Access the ``slot[slot].poles.two`` attribute.

        **Description:**
            - This attribute indicates if a two-pole setting is supported for the channels on the
              card.

        **Usage:**
            - Accessing this property will send the ``print(slot[slot].poles.two)`` query.

        **TSP Syntax:**

        ::

            - print(slot[slot].poles.two)

        **Info:**
            - ``slot``, the slot number (1 to 6).

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            if self._device.command_syntax_enabled:  # type: ignore[union-attr]
                return self._cmd_syntax + ".two"
            return self._device.query(f"print({self._cmd_syntax}.two)")  # type: ignore[union-attr]
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to access the ``{self._cmd_syntax}.two`` attribute."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error


class SlotItemInterlock(BaseTSPCmd):
    """The ``slot[slot].interlock`` command tree.

    **Info:**
        - ``slot``, the slot (1 to 6) containing the card to which the interlock state is applied.

    Properties/methods:
        - ``.override``: The ``slot[slot].interlock.override`` attribute.
        - ``.state``: The ``slot[slot].interlock.state`` attribute.
    """

    @property
    def override(self) -> str:
        """Access the ``slot[slot].interlock.override`` attribute.

        **Description:**
            - This attribute suppresses or permits interlock errors to be generated.

        **Usage:**
            - Accessing this property will send the ``print(slot[slot].interlock.override)`` query.
            - Setting this property to a value will send the
              ``slot[slot].interlock.override = value`` command.

        **TSP Syntax:**

        ::

            - slot[slot].interlock.override = value
            - print(slot[slot].interlock.override)

        **Info:**
            - ``slot``, the slot (1 to 6) containing the card to which the interlock state is
              applied.

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            if self._device.command_syntax_enabled:  # type: ignore[union-attr]
                return self._cmd_syntax + ".override"
            return self._device.query(  # type: ignore[union-attr]
                f"print({self._cmd_syntax}.override)"
            )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to access the ``{self._cmd_syntax}.override`` attribute."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    @override.setter
    def override(self, value: Union[str, float]) -> None:
        """Access the ``slot[slot].interlock.override`` attribute.

        **Description:**
            - This attribute suppresses or permits interlock errors to be generated.

        **Usage:**
            - Accessing this property will send the ``print(slot[slot].interlock.override)`` query.
            - Setting this property to a value will send the
              ``slot[slot].interlock.override = value`` command.

        **TSP Syntax:**

        ::

            - slot[slot].interlock.override = value
            - print(slot[slot].interlock.override)

        **Info:**
            - ``slot``, the slot (1 to 6) containing the card to which the interlock state is
              applied.

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            if self._device.command_verification_enabled:  # type: ignore[union-attr]
                self._device.set_and_check(  # type: ignore[union-attr]
                    self._cmd_syntax + ".override", value
                )
            else:
                self._device.write(  # type: ignore[union-attr]
                    f"{self._cmd_syntax}.override = {value}"
                )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to access the ``{self._cmd_syntax}.override`` attribute."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    @property
    def state(self) -> str:
        """Access the ``slot[slot].interlock.state`` attribute.

        **Description:**
            - This attribute indicates the interlock state of a card.

        **Usage:**
            - Accessing this property will send the ``print(slot[slot].interlock.state)`` query.

        **TSP Syntax:**

        ::

            - print(slot[slot].interlock.state)

        **Info:**
            - ``slot``, the slot (1 to 6) containing the card to which the interlock state is
              applied.

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            if self._device.command_syntax_enabled:  # type: ignore[union-attr]
                return self._cmd_syntax + ".state"
            return self._device.query(  # type: ignore[union-attr]
                f"print({self._cmd_syntax}.state)"
            )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to access the ``{self._cmd_syntax}.state`` attribute."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error


class SlotItemColumns(BaseTSPCmd):
    """The ``slot[slot].columns`` command tree.

    **Info:**
        - ``slot``, the slot number (1 to 6).

    Properties/methods:
        - ``.matrix``: The ``slot[slot].columns.matrix`` attribute.
    """

    @property
    def matrix(self) -> str:
        """Access the ``slot[slot].columns.matrix`` attribute.

        **Description:**
            - This attribute returns the number of columns in the matrix for the card in the
              specified slot.

        **Usage:**
            - Accessing this property will send the ``print(slot[slot].columns.matrix)`` query.

        **TSP Syntax:**

        ::

            - print(slot[slot].columns.matrix)

        **Info:**
            - ``slot``, the slot number (1 to 6).

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            if self._device.command_syntax_enabled:  # type: ignore[union-attr]
                return self._cmd_syntax + ".matrix"
            return self._device.query(  # type: ignore[union-attr]
                f"print({self._cmd_syntax}.matrix)"
            )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to access the ``{self._cmd_syntax}.matrix`` attribute."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error


class SlotItemBanks(BaseTSPCmd):
    """The ``slot[slot].banks`` command tree.

    **Info:**
        - ``slot``, the slot number.

    Properties/methods:
        - ``.matrix``: The ``slot[slot].banks.matrix`` attribute.
    """

    @property
    def matrix(self) -> str:
        """Access the ``slot[slot].banks.matrix`` attribute.

        **Description:**
            - This attribute describes the number of banks in the matrix for a card.

        **Usage:**
            - Accessing this property will send the ``print(slot[slot].banks.matrix)`` query.

        **TSP Syntax:**

        ::

            - print(slot[slot].banks.matrix)

        **Info:**
            - ``slot``, the slot number.

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            if self._device.command_syntax_enabled:  # type: ignore[union-attr]
                return self._cmd_syntax + ".matrix"
            return self._device.query(  # type: ignore[union-attr]
                f"print({self._cmd_syntax}.matrix)"
            )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to access the ``{self._cmd_syntax}.matrix`` attribute."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error


class SlotItem(ValidatedDynamicNumberCmd, BaseTSPCmd):
    """The ``slot[slot]`` command tree.

    **Info:**
        - ``slot``, the slot number.

    Properties/methods:
        - ``.banks``: The ``slot[slot].banks`` command tree.
        - ``.columns``: The ``slot[slot].columns`` command tree.
        - ``.commonsideohms``: The ``slot[slot].commonsideohms`` attribute.
        - ``.digio``: The ``slot[slot].digio`` attribute.
        - ``.idn``: The ``slot[slot].idn`` attribute.
        - ``.interlock``: The ``slot[slot].interlock`` command tree.
        - ``.isolated``: The ``slot[slot].isolated`` attribute.
        - ``.matrix``: The ``slot[slot].matrix`` attribute.
        - ``.maxvoltage``: The ``slot[slot].maxvoltage`` attribute.
        - ``.multiplexer``: The ``slot[slot].multiplexer`` attribute.
        - ``.poles``: The ``slot[slot].poles`` command tree.
        - ``.pseudocard``: The ``slot[slot].pseudocard`` attribute.
        - ``.rows``: The ``slot[slot].rows`` command tree.
        - ``.tempsensor``: The ``slot[slot].tempsensor`` attribute.
        - ``.thermal``: The ``slot[slot].thermal`` command tree.
    """

    def __init__(
        self, device: Optional["TSPDevice"] = None, cmd_syntax: str = "slot[slot]"
    ) -> None:
        super().__init__(device, cmd_syntax)
        self._banks = SlotItemBanks(device, f"{self._cmd_syntax}.banks")
        self._columns = SlotItemColumns(device, f"{self._cmd_syntax}.columns")
        self._interlock = SlotItemInterlock(device, f"{self._cmd_syntax}.interlock")
        self._poles = SlotItemPoles(device, f"{self._cmd_syntax}.poles")
        self._rows = SlotItemRows(device, f"{self._cmd_syntax}.rows")
        self._thermal = SlotItemThermal(device, f"{self._cmd_syntax}.thermal")

    @property
    def banks(self) -> SlotItemBanks:
        """Return the ``slot[slot].banks`` command tree.

        **Info:**
            - ``slot``, the slot number.

        Sub-properties/methods:
            - ``.matrix``: The ``slot[slot].banks.matrix`` attribute.
        """
        return self._banks

    @property
    def columns(self) -> SlotItemColumns:
        """Return the ``slot[slot].columns`` command tree.

        **Info:**
            - ``slot``, the slot number (1 to 6).

        Sub-properties/methods:
            - ``.matrix``: The ``slot[slot].columns.matrix`` attribute.
        """
        return self._columns

    @property
    def commonsideohms(self) -> str:
        """Access the ``slot[slot].commonsideohms`` attribute.

        **Description:**
            - This attribute indicates whether a card in the specified slot supports commonside
              channels for 4-wire resistance measurements.

        **Usage:**
            - Accessing this property will send the ``print(slot[slot].commonsideohms)`` query.

        **TSP Syntax:**

        ::

            - print(slot[slot].commonsideohms)

        **Info:**
            - ``slot``, the slot number (1 to 6).

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            if self._device.command_syntax_enabled:  # type: ignore[union-attr]
                return self._cmd_syntax + ".commonsideohms"
            return self._device.query(  # type: ignore[union-attr]
                f"print({self._cmd_syntax}.commonsideohms)"
            )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to access the ``{self._cmd_syntax}.commonsideohms`` attribute."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    @property
    def digio(self) -> str:
        """Access the ``slot[slot].digio`` attribute.

        **Description:**
            - This attribute indicates whether or not a card in the specified slot supports digital
              input and output channels.

        **Usage:**
            - Accessing this property will send the ``print(slot[slot].digio)`` query.

        **TSP Syntax:**

        ::

            - print(slot[slot].digio)

        **Info:**
            - ``slot``, the slot number (1 to 6).

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            if self._device.command_syntax_enabled:  # type: ignore[union-attr]
                return self._cmd_syntax + ".digio"
            return self._device.query(  # type: ignore[union-attr]
                f"print({self._cmd_syntax}.digio)"
            )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to access the ``{self._cmd_syntax}.digio`` attribute."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    @property
    def idn(self) -> str:
        """Access the ``slot[slot].idn`` attribute.

        **Description:**
            - This attribute returns a string that contains information about the plug-in card.

        **Usage:**
            - Accessing this property will send the ``print(slot[slot].idn)`` query.

        **TSP Syntax:**

        ::

            - print(slot[slot].idn)

        **Info:**
            - ``slot``, the slot number(1 to 6).

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            if self._device.command_syntax_enabled:  # type: ignore[union-attr]
                return self._cmd_syntax + ".idn"
            return self._device.query(f"print({self._cmd_syntax}.idn)")  # type: ignore[union-attr]
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to access the ``{self._cmd_syntax}.idn`` attribute."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    @property
    def interlock(self) -> SlotItemInterlock:
        """Return the ``slot[slot].interlock`` command tree.

        **Info:**
            - ``slot``, the slot (1 to 6) containing the card to which the interlock state is
              applied.

        Sub-properties/methods:
            - ``.override``: The ``slot[slot].interlock.override`` attribute.
            - ``.state``: The ``slot[slot].interlock.state`` attribute.
        """
        return self._interlock

    @property
    def isolated(self) -> str:
        """Access the ``slot[slot].isolated`` attribute.

        **Description:**
            - This attribute indicates if the card in the specified slot supports isolated channels.

        **Usage:**
            - Accessing this property will send the ``print(slot[slot].isolated)`` query.

        **TSP Syntax:**

        ::

            - print(slot[slot].isolated)

        **Info:**
            - ``slot``, the slot number (1 to 6).

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            if self._device.command_syntax_enabled:  # type: ignore[union-attr]
                return self._cmd_syntax + ".isolated"
            return self._device.query(  # type: ignore[union-attr]
                f"print({self._cmd_syntax}.isolated)"
            )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to access the ``{self._cmd_syntax}.isolated`` attribute."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    @property
    def matrix(self) -> str:
        """Access the ``slot[slot].matrix`` attribute.

        **Description:**
            - This attribute indicates if the card in the specified slot supports matrix channels.

        **Usage:**
            - Accessing this property will send the ``print(slot[slot].matrix)`` query.

        **TSP Syntax:**

        ::

            - print(slot[slot].matrix)

        **Info:**
            - ``slot``, the slot number (1 to 6).

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            if self._device.command_syntax_enabled:  # type: ignore[union-attr]
                return self._cmd_syntax + ".matrix"
            return self._device.query(  # type: ignore[union-attr]
                f"print({self._cmd_syntax}.matrix)"
            )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to access the ``{self._cmd_syntax}.matrix`` attribute."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    @property
    def maxvoltage(self) -> str:
        """Access the ``slot[slot].maxvoltage`` attribute.

        **Description:**
            - This attribute returns the maximum voltage of all channels on a plug-in card in the
              specified slot.

        **Usage:**
            - Accessing this property will send the ``print(slot[slot].maxvoltage)`` query.

        **TSP Syntax:**

        ::

            - print(slot[slot].maxvoltage)

        **Info:**
            - ``slot``, the slot number (1 to 6).

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            if self._device.command_syntax_enabled:  # type: ignore[union-attr]
                return self._cmd_syntax + ".maxvoltage"
            return self._device.query(  # type: ignore[union-attr]
                f"print({self._cmd_syntax}.maxvoltage)"
            )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to access the ``{self._cmd_syntax}.maxvoltage`` attribute."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    @property
    def multiplexer(self) -> str:
        """Access the ``slot[slot].multiplexer`` attribute.

        **Description:**
            - This attribute indicates if the card in the specified slot supports multiplexer
              channels.

        **Usage:**
            - Accessing this property will send the ``print(slot[slot].multiplexer)`` query.

        **TSP Syntax:**

        ::

            - print(slot[slot].multiplexer)

        **Info:**
            - ``slot``, the slot number (1 to 6).

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            if self._device.command_syntax_enabled:  # type: ignore[union-attr]
                return self._cmd_syntax + ".multiplexer"
            return self._device.query(  # type: ignore[union-attr]
                f"print({self._cmd_syntax}.multiplexer)"
            )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to access the ``{self._cmd_syntax}.multiplexer`` attribute."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    @property
    def poles(self) -> SlotItemPoles:
        """Return the ``slot[slot].poles`` command tree.

        **Info:**
            - ``slot``, the slot number (1 to 6).

        Sub-properties/methods:
            - ``.four``: The ``slot[slot].poles.four`` attribute.
            - ``.one``: The ``slot[slot].poles.one`` attribute.
            - ``.two``: The ``slot[slot].poles.two`` attribute.
        """
        return self._poles

    @property
    def pseudocard(self) -> str:
        """Access the ``slot[slot].pseudocard`` attribute.

        **Description:**
            - This attribute specifies a pseudocard to implement.

        **Usage:**
            - Accessing this property will send the ``print(slot[slot].pseudocard)`` query.
            - Setting this property to a value will send the ``slot[slot].pseudocard = value``
              command.

        **TSP Syntax:**

        ::

            - slot[slot].pseudocard = value
            - print(slot[slot].pseudocard)

        **Info:**
            - ``slot``, the slot number (1 to 6).

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            if self._device.command_syntax_enabled:  # type: ignore[union-attr]
                return self._cmd_syntax + ".pseudocard"
            return self._device.query(  # type: ignore[union-attr]
                f"print({self._cmd_syntax}.pseudocard)"
            )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to access the ``{self._cmd_syntax}.pseudocard`` attribute."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    @pseudocard.setter
    def pseudocard(self, value: Union[str, float]) -> None:
        """Access the ``slot[slot].pseudocard`` attribute.

        **Description:**
            - This attribute specifies a pseudocard to implement.

        **Usage:**
            - Accessing this property will send the ``print(slot[slot].pseudocard)`` query.
            - Setting this property to a value will send the ``slot[slot].pseudocard = value``
              command.

        **TSP Syntax:**

        ::

            - slot[slot].pseudocard = value
            - print(slot[slot].pseudocard)

        **Info:**
            - ``slot``, the slot number (1 to 6).

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            if self._device.command_verification_enabled:  # type: ignore[union-attr]
                self._device.set_and_check(  # type: ignore[union-attr]
                    self._cmd_syntax + ".pseudocard", value
                )
            else:
                self._device.write(  # type: ignore[union-attr]
                    f"{self._cmd_syntax}.pseudocard = {value}"
                )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to access the ``{self._cmd_syntax}.pseudocard`` attribute."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    @property
    def rows(self) -> SlotItemRows:
        """Return the ``slot[slot].rows`` command tree.

        **Info:**
            - ``slot``, the slot number (1 to 6).

        Sub-properties/methods:
            - ``.matrix``: The ``slot[slot].rows.matrix`` attribute.
        """
        return self._rows

    @property
    def tempsensor(self) -> str:
        """Access the ``slot[slot].tempsensor`` attribute.

        **Description:**
            - This attribute indicates if the module in the specified slot supports temperature
              sensor channels.

        **Usage:**
            - Accessing this property will send the ``print(slot[slot].tempsensor)`` query.

        **TSP Syntax:**

        ::

            - print(slot[slot].tempsensor)

        **Info:**
            - ``slot``, the slot number (1 to 6).

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            if self._device.command_syntax_enabled:  # type: ignore[union-attr]
                return self._cmd_syntax + ".tempsensor"
            return self._device.query(  # type: ignore[union-attr]
                f"print({self._cmd_syntax}.tempsensor)"
            )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to access the ``{self._cmd_syntax}.tempsensor`` attribute."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    @property
    def thermal(self) -> SlotItemThermal:
        """Return the ``slot[slot].thermal`` command tree.

        **Info:**
            - ``slot``, the slot number (1 to 6).

        Sub-properties/methods:
            - ``.state``: The ``slot[slot].thermal.state`` attribute.
        """
        return self._thermal



# pylint: disable=too-many-lines
"""The clock commands module.

These commands are used in the following models:
AWG70KA, AWG70KB

THIS FILE IS AUTO-GENERATED, IT SHOULD NOT BE MANUALLY MODIFIED.

Please report an issue if one is found.

Commands and Queries:

::

    - CLOCk:ECLock:DIVider <NR1>
    - CLOCk:ECLock:DIVider?
    - CLOCk:ECLock:FREQuency <NR3>
    - CLOCk:ECLock:FREQuency:ADJust
    - CLOCk:ECLock:FREQuency:DETect
    - CLOCk:ECLock:FREQuency?
    - CLOCk:ECLock:MULTiplier <NR1>
    - CLOCk:ECLock:MULTiplier?
    - CLOCk:EREFerence:DIVider <NR1>
    - CLOCk:EREFerence:DIVider?
    - CLOCk:EREFerence:FREQuency <NRf>
    - CLOCk:EREFerence:FREQuency:DETect
    - CLOCk:EREFerence:FREQuency?
    - CLOCk:EREFerence:MULTiplier <NR1>
    - CLOCk:EREFerence:MULTiplier?
    - CLOCk:JITTer {0|1|OFF|ON}
    - CLOCk:OUTPut:FREQuency?
    - CLOCk:OUTPut:STATe {0|1|OFF|ON}
    - CLOCk:OUTPut:STATe?
    - CLOCk:PHASe:ADJust:DEGRees <NR1>
    - CLOCk:PHASe:ADJust:DEGRees?
    - CLOCk:PHASe:ADJust:TIMe <NRf>
    - CLOCk:PHASe:ADJust:TIMe?
    - CLOCk:SOURce {INTernal|EFIXed|EVARiable|EXTernal}
    - CLOCk:SOURce?
    - CLOCk:SOUT:STATe {0|1|OFF|ON}
    - CLOCk:SOUT:STATe?
    - CLOCk:SRATe <NRf>
    - CLOCk:SRATe?
"""
from typing import Optional, TYPE_CHECKING

from .._helpers import SCPICmdRead, SCPICmdWrite, SCPICmdWriteNoArguments

if TYPE_CHECKING:
    from tm_devices.drivers.pi.pi_device import PIDevice


class ClockSrate(SCPICmdWrite, SCPICmdRead):
    r"""The ``CLOCk:SRATe`` command.

    **Description:**
        - This command sets or returns the sample rate for the clock. When ``CLOCk:SOURce`` is set
          to EXTernal, the maximum sample rate is: 4 \* External Clock In frequency (AWG70001)2 \*
          External Clock In frequency (AWG70002)

    **Usage:**
        - Using the ``.query()`` method will send the ``CLOCk:SRATe?`` query.
        - Using the ``.verify(value)`` method will send the ``CLOCk:SRATe?`` query and raise an
          AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``CLOCk:SRATe value`` command.

    **SCPI Syntax:**

    ::

        - CLOCk:SRATe <NRf>
        - CLOCk:SRATe?

    **Info:**
        - ``*RST`` sets this to the maximum value.
    """


class ClockSoutState(SCPICmdWrite, SCPICmdRead):
    """The ``CLOCk:SOUT:STATe`` command.

    **Description:**
        - This command sets or returns the state of the Sync Clock Out output.

    **Usage:**
        - Using the ``.query()`` method will send the ``CLOCk:SOUT:STATe?`` query.
        - Using the ``.verify(value)`` method will send the ``CLOCk:SOUT:STATe?`` query and raise an
          AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``CLOCk:SOUT:STATe value`` command.

    **SCPI Syntax:**

    ::

        - CLOCk:SOUT:STATe {0|1|OFF|ON}
        - CLOCk:SOUT:STATe?

    **Info:**
        - ``*RST`` sets this to 0.
    """


class ClockSout(SCPICmdRead):
    """The ``CLOCk:SOUT`` command tree.

    **Usage:**
        - Using the ``.query()`` method will send the ``CLOCk:SOUT?`` query.
        - Using the ``.verify(value)`` method will send the ``CLOCk:SOUT?`` query and raise an
          AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.state``: The ``CLOCk:SOUT:STATe`` command.
    """

    def __init__(self, device: Optional["PIDevice"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._state = ClockSoutState(device, f"{self._cmd_syntax}:STATe")

    @property
    def state(self) -> ClockSoutState:
        """Return the ``CLOCk:SOUT:STATe`` command.

        **Description:**
            - This command sets or returns the state of the Sync Clock Out output.

        **Usage:**
            - Using the ``.query()`` method will send the ``CLOCk:SOUT:STATe?`` query.
            - Using the ``.verify(value)`` method will send the ``CLOCk:SOUT:STATe?`` query and
              raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``CLOCk:SOUT:STATe value`` command.

        **SCPI Syntax:**

        ::

            - CLOCk:SOUT:STATe {0|1|OFF|ON}
            - CLOCk:SOUT:STATe?

        **Info:**
            - ``*RST`` sets this to 0.
        """
        return self._state


class ClockSource(SCPICmdWrite, SCPICmdRead):
    """The ``CLOCk:SOURce`` command.

    **Description:**
        - This command sets or returns the source of the clock.

    **Usage:**
        - Using the ``.query()`` method will send the ``CLOCk:SOURce?`` query.
        - Using the ``.verify(value)`` method will send the ``CLOCk:SOURce?`` query and raise an
          AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``CLOCk:SOURce value`` command.

    **SCPI Syntax:**

    ::

        - CLOCk:SOURce {INTernal|EFIXed|EVARiable|EXTernal}
        - CLOCk:SOURce?

    **Info:**
        - ``*RST`` sets this to INT.
    """


class ClockPhaseAdjustTime(SCPICmdWrite, SCPICmdRead):
    """The ``CLOCk:PHASe:ADJust:TIMe`` command.

    **Description:**
        - This command sets or returns the phase adjustment, in units of time, to synchronize
          multiple AWGs when using an external trigger. Setting the phase adjusts the phase of all
          signal outputs relative to the system clock.

    **Usage:**
        - Using the ``.query()`` method will send the ``CLOCk:PHASe:ADJust:TIMe?`` query.
        - Using the ``.verify(value)`` method will send the ``CLOCk:PHASe:ADJust:TIMe?`` query and
          raise an AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``CLOCk:PHASe:ADJust:TIMe value``
          command.

    **SCPI Syntax:**

    ::

        - CLOCk:PHASe:ADJust:TIMe <NRf>
        - CLOCk:PHASe:ADJust:TIMe?

    **Info:**
        - ``*RST`` sets this to 0 ps.
    """


class ClockPhaseAdjustDegrees(SCPICmdWrite, SCPICmdRead):
    """The ``CLOCk:PHASe:ADJust:DEGRees`` command.

    **Description:**
        - This command sets or returns the phase adjustment, in units of degrees, to synchronize
          multiple AWGs when using an external trigger. Setting the phase adjusts the phase of all
          signal outputs relative to the system clock.

    **Usage:**
        - Using the ``.query()`` method will send the ``CLOCk:PHASe:ADJust:DEGRees?`` query.
        - Using the ``.verify(value)`` method will send the ``CLOCk:PHASe:ADJust:DEGRees?`` query
          and raise an AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``CLOCk:PHASe:ADJust:DEGRees value``
          command.

    **SCPI Syntax:**

    ::

        - CLOCk:PHASe:ADJust:DEGRees <NR1>
        - CLOCk:PHASe:ADJust:DEGRees?

    **Info:**
        - ``*RST`` sets this to 0.
    """


class ClockPhaseAdjust(SCPICmdRead):
    """The ``CLOCk:PHASe:ADJust`` command tree.

    **Usage:**
        - Using the ``.query()`` method will send the ``CLOCk:PHASe:ADJust?`` query.
        - Using the ``.verify(value)`` method will send the ``CLOCk:PHASe:ADJust?`` query and raise
          an AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.degrees``: The ``CLOCk:PHASe:ADJust:DEGRees`` command.
        - ``.time``: The ``CLOCk:PHASe:ADJust:TIMe`` command.
    """

    def __init__(self, device: Optional["PIDevice"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._degrees = ClockPhaseAdjustDegrees(device, f"{self._cmd_syntax}:DEGRees")
        self._time = ClockPhaseAdjustTime(device, f"{self._cmd_syntax}:TIMe")

    @property
    def degrees(self) -> ClockPhaseAdjustDegrees:
        """Return the ``CLOCk:PHASe:ADJust:DEGRees`` command.

        **Description:**
            - This command sets or returns the phase adjustment, in units of degrees, to synchronize
              multiple AWGs when using an external trigger. Setting the phase adjusts the phase of
              all signal outputs relative to the system clock.

        **Usage:**
            - Using the ``.query()`` method will send the ``CLOCk:PHASe:ADJust:DEGRees?`` query.
            - Using the ``.verify(value)`` method will send the ``CLOCk:PHASe:ADJust:DEGRees?``
              query and raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``CLOCk:PHASe:ADJust:DEGRees value``
              command.

        **SCPI Syntax:**

        ::

            - CLOCk:PHASe:ADJust:DEGRees <NR1>
            - CLOCk:PHASe:ADJust:DEGRees?

        **Info:**
            - ``*RST`` sets this to 0.
        """
        return self._degrees

    @property
    def time(self) -> ClockPhaseAdjustTime:
        """Return the ``CLOCk:PHASe:ADJust:TIMe`` command.

        **Description:**
            - This command sets or returns the phase adjustment, in units of time, to synchronize
              multiple AWGs when using an external trigger. Setting the phase adjusts the phase of
              all signal outputs relative to the system clock.

        **Usage:**
            - Using the ``.query()`` method will send the ``CLOCk:PHASe:ADJust:TIMe?`` query.
            - Using the ``.verify(value)`` method will send the ``CLOCk:PHASe:ADJust:TIMe?`` query
              and raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``CLOCk:PHASe:ADJust:TIMe value``
              command.

        **SCPI Syntax:**

        ::

            - CLOCk:PHASe:ADJust:TIMe <NRf>
            - CLOCk:PHASe:ADJust:TIMe?

        **Info:**
            - ``*RST`` sets this to 0 ps.
        """
        return self._time


class ClockPhase(SCPICmdRead):
    """The ``CLOCk:PHASe`` command tree.

    **Usage:**
        - Using the ``.query()`` method will send the ``CLOCk:PHASe?`` query.
        - Using the ``.verify(value)`` method will send the ``CLOCk:PHASe?`` query and raise an
          AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.adjust``: The ``CLOCk:PHASe:ADJust`` command tree.
    """

    def __init__(self, device: Optional["PIDevice"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._adjust = ClockPhaseAdjust(device, f"{self._cmd_syntax}:ADJust")

    @property
    def adjust(self) -> ClockPhaseAdjust:
        """Return the ``CLOCk:PHASe:ADJust`` command tree.

        **Usage:**
            - Using the ``.query()`` method will send the ``CLOCk:PHASe:ADJust?`` query.
            - Using the ``.verify(value)`` method will send the ``CLOCk:PHASe:ADJust?`` query and
              raise an AssertionError if the returned value does not match ``value``.

        Sub-properties:
            - ``.degrees``: The ``CLOCk:PHASe:ADJust:DEGRees`` command.
            - ``.time``: The ``CLOCk:PHASe:ADJust:TIMe`` command.
        """
        return self._adjust


class ClockOutputState(SCPICmdWrite, SCPICmdRead):
    """The ``CLOCk:OUTPut:STATe`` command.

    **Description:**
        - This command sets or returns the state of the output clock (enabled or disabled). Enabling
          Clock Out provides a high speed clock (that is related to sample rate) to drive other
          devices or to measure.

    **Usage:**
        - Using the ``.query()`` method will send the ``CLOCk:OUTPut:STATe?`` query.
        - Using the ``.verify(value)`` method will send the ``CLOCk:OUTPut:STATe?`` query and raise
          an AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``CLOCk:OUTPut:STATe value`` command.

    **SCPI Syntax:**

    ::

        - CLOCk:OUTPut:STATe {0|1|OFF|ON}
        - CLOCk:OUTPut:STATe?

    **Info:**
        - ``*RST`` sets this to 0.
    """


class ClockOutputFrequency(SCPICmdRead):
    """The ``CLOCk:OUTPut:FREQuency`` command.

    **Description:**
        - This command returns the frequency of the output clock on the Clock Out connector.

    **Usage:**
        - Using the ``.query()`` method will send the ``CLOCk:OUTPut:FREQuency?`` query.
        - Using the ``.verify(value)`` method will send the ``CLOCk:OUTPut:FREQuency?`` query and
          raise an AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - CLOCk:OUTPut:FREQuency?
    """


class ClockOutput(SCPICmdRead):
    """The ``CLOCk:OUTPut`` command tree.

    **Usage:**
        - Using the ``.query()`` method will send the ``CLOCk:OUTPut?`` query.
        - Using the ``.verify(value)`` method will send the ``CLOCk:OUTPut?`` query and raise an
          AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.frequency``: The ``CLOCk:OUTPut:FREQuency`` command.
        - ``.state``: The ``CLOCk:OUTPut:STATe`` command.
    """

    def __init__(self, device: Optional["PIDevice"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._frequency = ClockOutputFrequency(device, f"{self._cmd_syntax}:FREQuency")
        self._state = ClockOutputState(device, f"{self._cmd_syntax}:STATe")

    @property
    def frequency(self) -> ClockOutputFrequency:
        """Return the ``CLOCk:OUTPut:FREQuency`` command.

        **Description:**
            - This command returns the frequency of the output clock on the Clock Out connector.

        **Usage:**
            - Using the ``.query()`` method will send the ``CLOCk:OUTPut:FREQuency?`` query.
            - Using the ``.verify(value)`` method will send the ``CLOCk:OUTPut:FREQuency?`` query
              and raise an AssertionError if the returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - CLOCk:OUTPut:FREQuency?
        """
        return self._frequency

    @property
    def state(self) -> ClockOutputState:
        """Return the ``CLOCk:OUTPut:STATe`` command.

        **Description:**
            - This command sets or returns the state of the output clock (enabled or disabled).
              Enabling Clock Out provides a high speed clock (that is related to sample rate) to
              drive other devices or to measure.

        **Usage:**
            - Using the ``.query()`` method will send the ``CLOCk:OUTPut:STATe?`` query.
            - Using the ``.verify(value)`` method will send the ``CLOCk:OUTPut:STATe?`` query and
              raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``CLOCk:OUTPut:STATe value`` command.

        **SCPI Syntax:**

        ::

            - CLOCk:OUTPut:STATe {0|1|OFF|ON}
            - CLOCk:OUTPut:STATe?

        **Info:**
            - ``*RST`` sets this to 0.
        """
        return self._state


class ClockJitter(SCPICmdWrite):
    """The ``CLOCk:JITTer`` command.

    **Description:**
        - This command sets or returns the state (enabled or disabled) to apply or not apply jitter
          reduction to the internal system clock or the clock signal applied to the Reference In
          connector.

    **Usage:**
        - Using the ``.write(value)`` method will send the ``CLOCk:JITTer value`` command.

    **SCPI Syntax:**

    ::

        - CLOCk:JITTer {0|1|OFF|ON}

    **Info:**
        - ``*RST`` sets this to 0.
    """


class ClockEreferenceMultiplier(SCPICmdWrite, SCPICmdRead):
    """The ``CLOCk:EREFerence:MULTiplier`` command.

    **Description:**
        - This command sets or returns the multiplier rate of the variable external reference
          signal.

    **Usage:**
        - Using the ``.query()`` method will send the ``CLOCk:EREFerence:MULTiplier?`` query.
        - Using the ``.verify(value)`` method will send the ``CLOCk:EREFerence:MULTiplier?`` query
          and raise an AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``CLOCk:EREFerence:MULTiplier value``
          command.

    **SCPI Syntax:**

    ::

        - CLOCk:EREFerence:MULTiplier <NR1>
        - CLOCk:EREFerence:MULTiplier?

    **Info:**
        - ``*RST`` sets this to 1.
    """


class ClockEreferenceFrequencyDetect(SCPICmdWriteNoArguments):
    """The ``CLOCk:EREFerence:FREQuency:DETect`` command.

    **Description:**
        - This command detects the frequency of the signal applied to the Reference In connector and
          adjusts the system to use the signal. The frequency is detected once each time the command
          executes. An error message is generated if no frequency is detected, is out of range, or
          if the adjustment fails. This command is only valid when the clock source is external.
          Errors are not returned. They are added to the system error queue which can be accessed
          with ``SYSTEM:ERROR:NEXT``.

    **Usage:**
        - Using the ``.write()`` method will send the ``CLOCk:EREFerence:FREQuency:DETect`` command.

    **SCPI Syntax:**

    ::

        - CLOCk:EREFerence:FREQuency:DETect
    """


class ClockEreferenceFrequency(SCPICmdWrite, SCPICmdRead):
    """The ``CLOCk:EREFerence:FREQuency`` command.

    **Description:**
        - This command sets or returns the expected frequency of the signal applied to the Reference
          In connector.

    **Usage:**
        - Using the ``.query()`` method will send the ``CLOCk:EREFerence:FREQuency?`` query.
        - Using the ``.verify(value)`` method will send the ``CLOCk:EREFerence:FREQuency?`` query
          and raise an AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``CLOCk:EREFerence:FREQuency value``
          command.

    **SCPI Syntax:**

    ::

        - CLOCk:EREFerence:FREQuency <NRf>
        - CLOCk:EREFerence:FREQuency?

    **Info:**
        - ``*RST`` sets this to 35 MHz.

    Properties:
        - ``.detect``: The ``CLOCk:EREFerence:FREQuency:DETect`` command.
    """

    def __init__(self, device: Optional["PIDevice"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._detect = ClockEreferenceFrequencyDetect(device, f"{self._cmd_syntax}:DETect")

    @property
    def detect(self) -> ClockEreferenceFrequencyDetect:
        """Return the ``CLOCk:EREFerence:FREQuency:DETect`` command.

        **Description:**
            - This command detects the frequency of the signal applied to the Reference In connector
              and adjusts the system to use the signal. The frequency is detected once each time the
              command executes. An error message is generated if no frequency is detected, is out of
              range, or if the adjustment fails. This command is only valid when the clock source is
              external. Errors are not returned. They are added to the system error queue which can
              be accessed with ``SYSTEM:ERROR:NEXT``.

        **Usage:**
            - Using the ``.write()`` method will send the ``CLOCk:EREFerence:FREQuency:DETect``
              command.

        **SCPI Syntax:**

        ::

            - CLOCk:EREFerence:FREQuency:DETect
        """
        return self._detect


class ClockEreferenceDivider(SCPICmdWrite, SCPICmdRead):
    """The ``CLOCk:EREFerence:DIVider`` command.

    **Description:**
        - This command sets or returns the divider rate of the external reference signal when the
          external reference is variable.

    **Usage:**
        - Using the ``.query()`` method will send the ``CLOCk:EREFerence:DIVider?`` query.
        - Using the ``.verify(value)`` method will send the ``CLOCk:EREFerence:DIVider?`` query and
          raise an AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``CLOCk:EREFerence:DIVider value``
          command.

    **SCPI Syntax:**

    ::

        - CLOCk:EREFerence:DIVider <NR1>
        - CLOCk:EREFerence:DIVider?

    **Info:**
        - ``*RST`` sets this to 1.
    """


class ClockEreference(SCPICmdRead):
    """The ``CLOCk:EREFerence`` command tree.

    **Usage:**
        - Using the ``.query()`` method will send the ``CLOCk:EREFerence?`` query.
        - Using the ``.verify(value)`` method will send the ``CLOCk:EREFerence?`` query and raise an
          AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.divider``: The ``CLOCk:EREFerence:DIVider`` command.
        - ``.frequency``: The ``CLOCk:EREFerence:FREQuency`` command.
        - ``.multiplier``: The ``CLOCk:EREFerence:MULTiplier`` command.
    """

    def __init__(self, device: Optional["PIDevice"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._divider = ClockEreferenceDivider(device, f"{self._cmd_syntax}:DIVider")
        self._frequency = ClockEreferenceFrequency(device, f"{self._cmd_syntax}:FREQuency")
        self._multiplier = ClockEreferenceMultiplier(device, f"{self._cmd_syntax}:MULTiplier")

    @property
    def divider(self) -> ClockEreferenceDivider:
        """Return the ``CLOCk:EREFerence:DIVider`` command.

        **Description:**
            - This command sets or returns the divider rate of the external reference signal when
              the external reference is variable.

        **Usage:**
            - Using the ``.query()`` method will send the ``CLOCk:EREFerence:DIVider?`` query.
            - Using the ``.verify(value)`` method will send the ``CLOCk:EREFerence:DIVider?`` query
              and raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``CLOCk:EREFerence:DIVider value``
              command.

        **SCPI Syntax:**

        ::

            - CLOCk:EREFerence:DIVider <NR1>
            - CLOCk:EREFerence:DIVider?

        **Info:**
            - ``*RST`` sets this to 1.
        """
        return self._divider

    @property
    def frequency(self) -> ClockEreferenceFrequency:
        """Return the ``CLOCk:EREFerence:FREQuency`` command.

        **Description:**
            - This command sets or returns the expected frequency of the signal applied to the
              Reference In connector.

        **Usage:**
            - Using the ``.query()`` method will send the ``CLOCk:EREFerence:FREQuency?`` query.
            - Using the ``.verify(value)`` method will send the ``CLOCk:EREFerence:FREQuency?``
              query and raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``CLOCk:EREFerence:FREQuency value``
              command.

        **SCPI Syntax:**

        ::

            - CLOCk:EREFerence:FREQuency <NRf>
            - CLOCk:EREFerence:FREQuency?

        **Info:**
            - ``*RST`` sets this to 35 MHz.

        Sub-properties:
            - ``.detect``: The ``CLOCk:EREFerence:FREQuency:DETect`` command.
        """
        return self._frequency

    @property
    def multiplier(self) -> ClockEreferenceMultiplier:
        """Return the ``CLOCk:EREFerence:MULTiplier`` command.

        **Description:**
            - This command sets or returns the multiplier rate of the variable external reference
              signal.

        **Usage:**
            - Using the ``.query()`` method will send the ``CLOCk:EREFerence:MULTiplier?`` query.
            - Using the ``.verify(value)`` method will send the ``CLOCk:EREFerence:MULTiplier?``
              query and raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``CLOCk:EREFerence:MULTiplier value``
              command.

        **SCPI Syntax:**

        ::

            - CLOCk:EREFerence:MULTiplier <NR1>
            - CLOCk:EREFerence:MULTiplier?

        **Info:**
            - ``*RST`` sets this to 1.
        """
        return self._multiplier


class ClockEclockMultiplier(SCPICmdWrite, SCPICmdRead):
    """The ``CLOCk:ECLock:MULTiplier`` command.

    **Description:**
        - This command sets or returns the multiplier rate of the external clock.

    **Usage:**
        - Using the ``.query()`` method will send the ``CLOCk:ECLock:MULTiplier?`` query.
        - Using the ``.verify(value)`` method will send the ``CLOCk:ECLock:MULTiplier?`` query and
          raise an AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``CLOCk:ECLock:MULTiplier value``
          command.

    **SCPI Syntax:**

    ::

        - CLOCk:ECLock:MULTiplier <NR1>
        - CLOCk:ECLock:MULTiplier?

    **Info:**
        - ``*RST`` sets this to 1.
    """


class ClockEclockFrequencyDetect(SCPICmdWriteNoArguments):
    """The ``CLOCk:ECLock:FREQuency:DETect`` command.

    **Description:**
        - This command detects the frequency of the signal applied to the Clock In connector and
          adjusts the system to use the signal. The frequency is detected once each time the command
          executes. An error message is generated if no frequency is detected or is out of range.

    **Usage:**
        - Using the ``.write()`` method will send the ``CLOCk:ECLock:FREQuency:DETect`` command.

    **SCPI Syntax:**

    ::

        - CLOCk:ECLock:FREQuency:DETect
    """


class ClockEclockFrequencyAdjust(SCPICmdWriteNoArguments):
    """The ``CLOCk:ECLock:FREQuency:ADJust`` command.

    **Description:**
        - This command initiates an adjustment (calibration) to the system clock circuitry. The
          adjustment can be run at any time, but if the system detects setting changes that impact
          clock accuracy, the adjustment is required before any signals can be played. A message is
          displayed in the status area when an adjustment is required. A error message is generated
          if the adjustment fails.

    **Usage:**
        - Using the ``.write()`` method will send the ``CLOCk:ECLock:FREQuency:ADJust`` command.

    **SCPI Syntax:**

    ::

        - CLOCk:ECLock:FREQuency:ADJust
    """


class ClockEclockFrequency(SCPICmdWrite, SCPICmdRead):
    """The ``CLOCk:ECLock:FREQuency`` command.

    **Description:**
        - This command sets or returns the expected frequency being provided by the external clock.

    **Usage:**
        - Using the ``.query()`` method will send the ``CLOCk:ECLock:FREQuency?`` query.
        - Using the ``.verify(value)`` method will send the ``CLOCk:ECLock:FREQuency?`` query and
          raise an AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``CLOCk:ECLock:FREQuency value`` command.

    **SCPI Syntax:**

    ::

        - CLOCk:ECLock:FREQuency <NR3>
        - CLOCk:ECLock:FREQuency?

    **Info:**
        - ``*RST`` sets this to 6.25 GHz.

    Properties:
        - ``.adjust``: The ``CLOCk:ECLock:FREQuency:ADJust`` command.
        - ``.detect``: The ``CLOCk:ECLock:FREQuency:DETect`` command.
    """

    def __init__(self, device: Optional["PIDevice"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._adjust = ClockEclockFrequencyAdjust(device, f"{self._cmd_syntax}:ADJust")
        self._detect = ClockEclockFrequencyDetect(device, f"{self._cmd_syntax}:DETect")

    @property
    def adjust(self) -> ClockEclockFrequencyAdjust:
        """Return the ``CLOCk:ECLock:FREQuency:ADJust`` command.

        **Description:**
            - This command initiates an adjustment (calibration) to the system clock circuitry. The
              adjustment can be run at any time, but if the system detects setting changes that
              impact clock accuracy, the adjustment is required before any signals can be played. A
              message is displayed in the status area when an adjustment is required. A error
              message is generated if the adjustment fails.

        **Usage:**
            - Using the ``.write()`` method will send the ``CLOCk:ECLock:FREQuency:ADJust`` command.

        **SCPI Syntax:**

        ::

            - CLOCk:ECLock:FREQuency:ADJust
        """
        return self._adjust

    @property
    def detect(self) -> ClockEclockFrequencyDetect:
        """Return the ``CLOCk:ECLock:FREQuency:DETect`` command.

        **Description:**
            - This command detects the frequency of the signal applied to the Clock In connector and
              adjusts the system to use the signal. The frequency is detected once each time the
              command executes. An error message is generated if no frequency is detected or is out
              of range.

        **Usage:**
            - Using the ``.write()`` method will send the ``CLOCk:ECLock:FREQuency:DETect`` command.

        **SCPI Syntax:**

        ::

            - CLOCk:ECLock:FREQuency:DETect
        """
        return self._detect


class ClockEclockDivider(SCPICmdWrite, SCPICmdRead):
    """The ``CLOCk:ECLock:DIVider`` command.

    **Description:**
        - This command sets or returns the divider rate for the external clock.

    **Usage:**
        - Using the ``.query()`` method will send the ``CLOCk:ECLock:DIVider?`` query.
        - Using the ``.verify(value)`` method will send the ``CLOCk:ECLock:DIVider?`` query and
          raise an AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``CLOCk:ECLock:DIVider value`` command.

    **SCPI Syntax:**

    ::

        - CLOCk:ECLock:DIVider <NR1>
        - CLOCk:ECLock:DIVider?

    **Info:**
        - ``*RST`` sets this to 1.
    """


class ClockEclock(SCPICmdRead):
    """The ``CLOCk:ECLock`` command tree.

    **Usage:**
        - Using the ``.query()`` method will send the ``CLOCk:ECLock?`` query.
        - Using the ``.verify(value)`` method will send the ``CLOCk:ECLock?`` query and raise an
          AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.divider``: The ``CLOCk:ECLock:DIVider`` command.
        - ``.frequency``: The ``CLOCk:ECLock:FREQuency`` command.
        - ``.multiplier``: The ``CLOCk:ECLock:MULTiplier`` command.
    """

    def __init__(self, device: Optional["PIDevice"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._divider = ClockEclockDivider(device, f"{self._cmd_syntax}:DIVider")
        self._frequency = ClockEclockFrequency(device, f"{self._cmd_syntax}:FREQuency")
        self._multiplier = ClockEclockMultiplier(device, f"{self._cmd_syntax}:MULTiplier")

    @property
    def divider(self) -> ClockEclockDivider:
        """Return the ``CLOCk:ECLock:DIVider`` command.

        **Description:**
            - This command sets or returns the divider rate for the external clock.

        **Usage:**
            - Using the ``.query()`` method will send the ``CLOCk:ECLock:DIVider?`` query.
            - Using the ``.verify(value)`` method will send the ``CLOCk:ECLock:DIVider?`` query and
              raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``CLOCk:ECLock:DIVider value``
              command.

        **SCPI Syntax:**

        ::

            - CLOCk:ECLock:DIVider <NR1>
            - CLOCk:ECLock:DIVider?

        **Info:**
            - ``*RST`` sets this to 1.
        """
        return self._divider

    @property
    def frequency(self) -> ClockEclockFrequency:
        """Return the ``CLOCk:ECLock:FREQuency`` command.

        **Description:**
            - This command sets or returns the expected frequency being provided by the external
              clock.

        **Usage:**
            - Using the ``.query()`` method will send the ``CLOCk:ECLock:FREQuency?`` query.
            - Using the ``.verify(value)`` method will send the ``CLOCk:ECLock:FREQuency?`` query
              and raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``CLOCk:ECLock:FREQuency value``
              command.

        **SCPI Syntax:**

        ::

            - CLOCk:ECLock:FREQuency <NR3>
            - CLOCk:ECLock:FREQuency?

        **Info:**
            - ``*RST`` sets this to 6.25 GHz.

        Sub-properties:
            - ``.adjust``: The ``CLOCk:ECLock:FREQuency:ADJust`` command.
            - ``.detect``: The ``CLOCk:ECLock:FREQuency:DETect`` command.
        """
        return self._frequency

    @property
    def multiplier(self) -> ClockEclockMultiplier:
        """Return the ``CLOCk:ECLock:MULTiplier`` command.

        **Description:**
            - This command sets or returns the multiplier rate of the external clock.

        **Usage:**
            - Using the ``.query()`` method will send the ``CLOCk:ECLock:MULTiplier?`` query.
            - Using the ``.verify(value)`` method will send the ``CLOCk:ECLock:MULTiplier?`` query
              and raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``CLOCk:ECLock:MULTiplier value``
              command.

        **SCPI Syntax:**

        ::

            - CLOCk:ECLock:MULTiplier <NR1>
            - CLOCk:ECLock:MULTiplier?

        **Info:**
            - ``*RST`` sets this to 1.
        """
        return self._multiplier


#  pylint: disable=too-many-instance-attributes
class Clock(SCPICmdRead):
    """The ``CLOCk`` command tree.

    **Usage:**
        - Using the ``.query()`` method will send the ``CLOCk?`` query.
        - Using the ``.verify(value)`` method will send the ``CLOCk?`` query and raise an
          AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.eclock``: The ``CLOCk:ECLock`` command tree.
        - ``.ereference``: The ``CLOCk:EREFerence`` command tree.
        - ``.jitter``: The ``CLOCk:JITTer`` command.
        - ``.output``: The ``CLOCk:OUTPut`` command tree.
        - ``.phase``: The ``CLOCk:PHASe`` command tree.
        - ``.source``: The ``CLOCk:SOURce`` command.
        - ``.sout``: The ``CLOCk:SOUT`` command tree.
        - ``.srate``: The ``CLOCk:SRATe`` command.
    """

    def __init__(self, device: Optional["PIDevice"] = None, cmd_syntax: str = "CLOCk") -> None:
        super().__init__(device, cmd_syntax)
        self._eclock = ClockEclock(device, f"{self._cmd_syntax}:ECLock")
        self._ereference = ClockEreference(device, f"{self._cmd_syntax}:EREFerence")
        self._jitter = ClockJitter(device, f"{self._cmd_syntax}:JITTer")
        self._output = ClockOutput(device, f"{self._cmd_syntax}:OUTPut")
        self._phase = ClockPhase(device, f"{self._cmd_syntax}:PHASe")
        self._source = ClockSource(device, f"{self._cmd_syntax}:SOURce")
        self._sout = ClockSout(device, f"{self._cmd_syntax}:SOUT")
        self._srate = ClockSrate(device, f"{self._cmd_syntax}:SRATe")

    @property
    def eclock(self) -> ClockEclock:
        """Return the ``CLOCk:ECLock`` command tree.

        **Usage:**
            - Using the ``.query()`` method will send the ``CLOCk:ECLock?`` query.
            - Using the ``.verify(value)`` method will send the ``CLOCk:ECLock?`` query and raise an
              AssertionError if the returned value does not match ``value``.

        Sub-properties:
            - ``.divider``: The ``CLOCk:ECLock:DIVider`` command.
            - ``.frequency``: The ``CLOCk:ECLock:FREQuency`` command.
            - ``.multiplier``: The ``CLOCk:ECLock:MULTiplier`` command.
        """
        return self._eclock

    @property
    def ereference(self) -> ClockEreference:
        """Return the ``CLOCk:EREFerence`` command tree.

        **Usage:**
            - Using the ``.query()`` method will send the ``CLOCk:EREFerence?`` query.
            - Using the ``.verify(value)`` method will send the ``CLOCk:EREFerence?`` query and
              raise an AssertionError if the returned value does not match ``value``.

        Sub-properties:
            - ``.divider``: The ``CLOCk:EREFerence:DIVider`` command.
            - ``.frequency``: The ``CLOCk:EREFerence:FREQuency`` command.
            - ``.multiplier``: The ``CLOCk:EREFerence:MULTiplier`` command.
        """
        return self._ereference

    @property
    def jitter(self) -> ClockJitter:
        """Return the ``CLOCk:JITTer`` command.

        **Description:**
            - This command sets or returns the state (enabled or disabled) to apply or not apply
              jitter reduction to the internal system clock or the clock signal applied to the
              Reference In connector.

        **Usage:**
            - Using the ``.write(value)`` method will send the ``CLOCk:JITTer value`` command.

        **SCPI Syntax:**

        ::

            - CLOCk:JITTer {0|1|OFF|ON}

        **Info:**
            - ``*RST`` sets this to 0.
        """
        return self._jitter

    @property
    def output(self) -> ClockOutput:
        """Return the ``CLOCk:OUTPut`` command tree.

        **Usage:**
            - Using the ``.query()`` method will send the ``CLOCk:OUTPut?`` query.
            - Using the ``.verify(value)`` method will send the ``CLOCk:OUTPut?`` query and raise an
              AssertionError if the returned value does not match ``value``.

        Sub-properties:
            - ``.frequency``: The ``CLOCk:OUTPut:FREQuency`` command.
            - ``.state``: The ``CLOCk:OUTPut:STATe`` command.
        """
        return self._output

    @property
    def phase(self) -> ClockPhase:
        """Return the ``CLOCk:PHASe`` command tree.

        **Usage:**
            - Using the ``.query()`` method will send the ``CLOCk:PHASe?`` query.
            - Using the ``.verify(value)`` method will send the ``CLOCk:PHASe?`` query and raise an
              AssertionError if the returned value does not match ``value``.

        Sub-properties:
            - ``.adjust``: The ``CLOCk:PHASe:ADJust`` command tree.
        """
        return self._phase

    @property
    def source(self) -> ClockSource:
        """Return the ``CLOCk:SOURce`` command.

        **Description:**
            - This command sets or returns the source of the clock.

        **Usage:**
            - Using the ``.query()`` method will send the ``CLOCk:SOURce?`` query.
            - Using the ``.verify(value)`` method will send the ``CLOCk:SOURce?`` query and raise an
              AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``CLOCk:SOURce value`` command.

        **SCPI Syntax:**

        ::

            - CLOCk:SOURce {INTernal|EFIXed|EVARiable|EXTernal}
            - CLOCk:SOURce?

        **Info:**
            - ``*RST`` sets this to INT.
        """
        return self._source

    @property
    def sout(self) -> ClockSout:
        """Return the ``CLOCk:SOUT`` command tree.

        **Usage:**
            - Using the ``.query()`` method will send the ``CLOCk:SOUT?`` query.
            - Using the ``.verify(value)`` method will send the ``CLOCk:SOUT?`` query and raise an
              AssertionError if the returned value does not match ``value``.

        Sub-properties:
            - ``.state``: The ``CLOCk:SOUT:STATe`` command.
        """
        return self._sout

    @property
    def srate(self) -> ClockSrate:
        r"""Return the ``CLOCk:SRATe`` command.

        **Description:**
            - This command sets or returns the sample rate for the clock. When ``CLOCk:SOURce`` is
              set to EXTernal, the maximum sample rate is: 4 \* External Clock In frequency
              (AWG70001)2 \* External Clock In frequency (AWG70002)

        **Usage:**
            - Using the ``.query()`` method will send the ``CLOCk:SRATe?`` query.
            - Using the ``.verify(value)`` method will send the ``CLOCk:SRATe?`` query and raise an
              AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``CLOCk:SRATe value`` command.

        **SCPI Syntax:**

        ::

            - CLOCk:SRATe <NRf>
            - CLOCk:SRATe?

        **Info:**
            - ``*RST`` sets this to the maximum value.
        """
        return self._srate
